@@ -8,6 +8,8 @@ from typing import Type
 import onnxruntime as ort
 import pooch
 
+from .session_modnet import ModNetSession
+
 from .session_base import BaseSession
 from .session_cloth import ClothSession
 from .session_dis import DisSession
@@ -44,6 +46,10 @@ def new_session(model_name: str = "u2net") -> BaseSession:
         md5 = "fc16ebd8b0c10d971d3513d564d01e29"
         url = "https://github.com/syedusama5556/removebg_infusiblecoder/releases/download/v0.0.0/isnet-general-use.onnx"
         session_class = DisSession
+    elif model_name == "modnet":
+        md5 = "d0ded73e80bc0d38a64e2286486e4ea3"
+        url = "https://github.com/syedusama5556/removebg_infusiblecoder/releases/download/v0.0.0/modnet_photographic_portrait_matting.onnx"
+        session_class = ModNetSession
 
     u2net_home = os.getenv(
         "U2NET_HOME", os.path.join(os.getenv("XDG_DATA_HOME", "~"), ".u2net")
